@@ -622,7 +622,7 @@ function resolver:getsocket(servernum)    -- - - - - - - - - - - - - getsocket
 	local sock = self.socket[servernum];
 	if sock then return sock; end
 
-	local err;
+	local ok, err;
 	sock, err = socket.udp();
 	if sock and self.socket_wrapper then sock, err = self.socket_wrapper(sock, self); end
 	if not sock then
@@ -630,10 +630,14 @@ function resolver:getsocket(servernum)    -- - - - - - - - - - - - - getsocket
 	end
 	sock:settimeout(0);
 	-- todo: attempt to use a random port, fallback to 0
-	sock:setsockname('*', 0);
-	sock:setpeername(self.server[servernum], 53);
 	self.socket[servernum] = sock;
 	self.socketset[sock] = servernum;
+	-- set{sock,peer}name can fail, eg because of local routing table
+	-- if so, try the next server
+	ok, err = sock:setsockname('*', 0);
+	if not ok then return self:servfail(sock, err); end
+	ok, err = sock:setpeername(self.server[servernum], 53);
+	if not ok then return self:servfail(sock, err); end
 	return sock;
 end
 
@@ -781,13 +785,13 @@ function resolver:query(qname, qtype, qclass)    -- - - - - - - - - - -- query
 	return true;
 end
 
-function resolver:servfail(sock)
+function resolver:servfail(sock, err)
 	-- Resend all queries for this server
 
 	local num = self.socketset[sock]
 
 	-- Socket is dead now
-	self:voidsocket(sock);
+	sock = self:voidsocket(sock);
 
 	-- Find all requests to the down server, and retry on the next server
 	self.time = socket.gettime();
@@ -804,8 +808,8 @@ function resolver:servfail(sock)
 					--print('timeout');
 					queries[question] = nil;
 				else
-					local _a = self:getsocket(o.server);
-					if _a then _a:send(o.packet); end
+					sock, err = self:getsocket(o.server);
+					if sock then sock:send(o.packet); end
 				end
 			end
 		end
@@ -821,6 +825,7 @@ function resolver:servfail(sock)
 			self.best_server = 1;
 		end
 	end
+	return sock, err;
 end
 
 function resolver:settimeout(seconds)
