@@ -155,7 +155,7 @@ function stanza_handler(event)
 			return true;
 		end
 		if not(restrict_room_creation) or
-		  (restrict_room_creation == "admin" and is_admin(stanza.attr.from)) or
+		  is_admin(stanza.attr.from) or
 		  (restrict_room_creation == "local" and select(2, jid_split(stanza.attr.from)) == module.host:gsub("^[^%.]+%.", "")) then
 			room = create_room(bare);
 		end
@@ -163,6 +163,7 @@ function stanza_handler(event)
 	if room then
 		room:handle_stanza(origin, stanza);
 		if not next(room._occupants) and not persistent_rooms[room.jid] then -- empty, non-persistent room
+			module:fire_event("muc-room-destroyed", { room = room });
 			rooms[bare] = nil; -- discard room
 		end
 	else
