@@ -225,7 +225,7 @@ function room_mt:get_disco_info(stanza)
 		:tag("feature", {var=self._data.whois ~= "anyone" and "muc_semianonymous" or "muc_nonanonymous"}):up()
 		:add_child(dataform.new({
 			{ name = "FORM_TYPE", type = "hidden", value = "http://jabber.org/protocol/muc#roominfo" },
-			{ name = "muc#roominfo_description", label = "Description"},
+			{ name = "muc#roominfo_description", label = "Description", value = "" },
 			{ name = "muc#roominfo_occupants", label = "Number of occupants", value = tostring(count) }
 		}):form({["muc#roominfo_description"] = self:get_description()}, 'result'))
 	;
@@ -1060,7 +1060,7 @@ function room_mt:can_set_role(actor_jid, occupant_jid, role)
 	if actor_jid == true then return true; end
 
 	local actor = self._occupants[self._jid_nick[actor_jid]];
-	if actor.role == "moderator" then
+	if actor and actor.role == "moderator" then
 		if occupant.affiliation ~= "owner" and occupant.affiliation ~= "admin" then
 			if actor.affiliation == "owner" or actor.affiliation == "admin" then
 				return true;
